﻿using System;
using System.IO;
using BITKit;
using BITKit.CommandPattern;
using BITKit.Mod;
using System.Linq;
using BITFactory.Cutting;

namespace BITFactory.Cutting.Mod
{
	/// <summary>
	/// 该程序将自动保存导出的数据到同级目录下
	/// </summary>
	public sealed class AutoSaveImage : MyMod
	{
		public override string PackageName { get; set; } = "iFactory.Cutting.Mod.auto_save_images";
		public override string Name { get; set; } = "自动保存导出数据";

		[Inject] private ICuttingTool _cuttingTool;

		public override void OnInitialized()
		{
			base.OnInitialized();
			_cuttingTool.OnRelease += OnRelease;
		}

		public override void OnDisposed()
		{
			base.OnDisposed();
			_cuttingTool.OnRelease -= OnRelease;
		}

		private void OnRelease(ICommand[] obj)
		{
			var commands = obj.OfType<ICuttingCommand>().ToArray();
			var stringBuilder = new System.Text.StringBuilder();
			var path = Path.Combine(FolderPath, $"export_{DateTime.Now.Ticks}.cfg");
			stringBuilder.AppendLine($"导出时间: {DateTime.Now},导出命令数量: {commands.Length}");
			foreach (var command in commands)
			{
				if(command is CuttingPointCommand pointCommand)
				{
					stringBuilder.AppendLine(
						$"切削点: {pointCommand.PlanePoint.x} {pointCommand.PlanePoint.y} {pointCommand.PlanePoint.z}");
				}
				else if(command is CuttingLineCommand lineCommand)
				{
					stringBuilder.AppendLine($"切削线:{lineCommand.Line.Length}");
					foreach (var linePos in lineCommand.Line)
					{
						stringBuilder.AppendLine($"切削线点: {linePos.x} {linePos.y} {linePos.z}");
					}
				}
				else
				{
					stringBuilder.AppendLine($"{command.Name}:{command}");
				}
				// switch (command)
				// {
				// 	case CuttingPointCommand pointCommand:
				// 		stringBuilder.AppendLine(
				// 			$"切削点: {pointCommand.PlanePoint.x} {pointCommand.PlanePoint.y} {pointCommand.PlanePoint.z}");
				// 		break;
				// 	case CuttingLineCommand lineCommand:
				// 		stringBuilder.AppendLine($"切削线:{lineCommand.Line.Length}");
				// 		foreach (var linePos in lineCommand.Line)
				// 		{
				// 			stringBuilder.AppendLine($"切削线点: {linePos.x} {linePos.y} {linePos.z}");
				// 		}
				// 		break;
				// }
			}

			File.WriteAllText(path, stringBuilder.ToString());

			BIT4Log.Log<AutoSaveImage>($"导出数据已保存到:{path}");
		}
	}
}